@@ -1,6 +1,6 @@
 #!/bin/sh
 # -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -28,8 +28,12 @@
 #-#  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 crfile=`mktemp`
+crfilevim=`mktemp`
 cat < COPYING  | sed 's/^/#-# /' > "$crfile"
+cat < COPYING  | sed 's/^/"#-# /' > "$crfilevim"
+
 n=0
+tmpfile="tmpfile"
 while [ "$1" ] ; do
    f="$1"
    shift
@@ -45,10 +49,24 @@ while [ "$1" ] ; do
    # following 2 sed commands take care that only the first '-copyright-'
    # will be followed by the copyright text
    # Notice that sed requires a newline after the filename of the 'r' command
-   sed -i "/^\s*#-#/d" "$f"
-   sed -i "/$txt/{r $crfile
-:a;n;ba;}" "$f"
+   # Not using 'sed -i' because not all sed's interpret this the same
+   case "$f" in
+      *.vim)
+          sed "/^[ 	]*\"#-#/d" "$f" > "$tmpfile" && cp "$tmpfile" "$f"
+	  cr=$crfilevim
+	 ;;
+      *)
+          sed "/^[ 	]*#-#/d" "$f" > "$tmpfile" && cp "$tmpfile" "$f"
+	  cr=$crfile
+         ;;
+   esac
+
+   sed "/$txt/{r $cr
+:a
+n
+ba
+}" "$f" > "$tmpfile" && cp "$tmpfile" "$f"
    n=`expr $n + 1`
 done
 echo "$n files copyrighted"
-
+rm -f "$tmpfile" "$crfile" "$crfilevim"
