@@ -258,7 +258,7 @@ void Docs::usage(bool man)
    manout("--indent_segment=<n>              ","SEGMENT      indent.");
 #endif
    manout("-s<n>, --indent_select=<n>        ","SELECT       indent.");
-   manout("-t<n>, --indent_type=<n>          ","TYPE         indent.");
+   manout("-t<n>, --indent_type=<n>          ","TYPE, STRUCTURE, UNION, MAP indent.");
    manout("-w<n>, --indent_where=<n>         ","WHERE        indent.");
    manout("-x<n>, --indent_critical=<n>      ","CRITICAL     indent.");
    manout("--indent_changeteam=<n>           ","CHANGE TEAM  indent.");
@@ -473,18 +473,6 @@ void Docs::usage(bool man)
    manout(" "," If the fortran source contains label-related errors, or when");
    manout(" ","findent misbehaves, relabeling can create havoc. So: test.");
 
-
-   if(doman)
-   {
-      std::cout << ".SH DONATIONS" << std::endl;
-      std::cout << ".br"           << std::endl;
-   }
-   else
-   {
-      std::cout << "DONATIONS"     << std::endl;
-   }
-   manout(" ","Donations to support the maintenance of this program are welcome: ");
-   manout(" ","https://paypal.me/wvermin");
    if(doman)
    {
       std::cout << ".SH COPYRIGHT" << std::endl;
