@@ -757,6 +757,9 @@ void Fortran::indent_and_output()
 	 switch(props.kind)   //determine indent, refactor
 	 {
 	    case TYPE:
+	    case STRUCTURE:
+	    case UNION:
+	    case MAP:
 	       Cur_indent = top_indent();
 	       push_indent(Cur_indent + FLAGS.type_indent);
 	       empty_dolabels();
@@ -856,16 +859,19 @@ void Fortran::indent_and_output()
 	    case ENDSELECT:
 	    case ENDTEAM:
 	    case ENDWHERE:
+	    case ENDSTRUCTURE:
+	    case ENDUNION:
+	    case ENDMAP:
 	       D(O("indent_handled:");O(indent_handled););
 	       if (!indent_handled && !first_code_line)
 		  Cur_indent = pop_indent();
 	       break;
 	    case PROCEDURE:  // in fact: moduleprocedure
-	       //
-	       // depending on what follows this will be 
-	       // recognized as a module procedure with content
-	       // or only a moduleprocedure specification
-	       //
+			     //
+			     // depending on what follows this will be 
+			     // recognized as a module procedure with content
+			     // or only a moduleprocedure specification
+			     //
 	       break;
 	    case CONTAINS:
 	       if (FLAGS.indent_contain)
