@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -371,7 +371,10 @@ class Fortranline
 	 case COCO_IF: case COCO_ENDIF: case COCO_ELSE: case COCO_ELIF: case COCO: 
 	    return COCO;
 	    break;
-	 case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO:
+	 case FYPP_IF: case FYPP_ENDIF: case FYPP_ELSE: case FYPP_ELIF: case FYPP: 
+	    return FYPP;
+	    break;
+	 case INCLUDE_CPP: case INCLUDE_CPP_STD: case INCLUDE_COCO: case INCLUDE_FYPP:
 	    return pretype;
 	    break;
 	 default:
@@ -383,7 +386,9 @@ class Fortranline
 
    bool precoco(void)                 { return first2chars() == "??"; }
 
-   bool pre(void)                     { return precpp() || precoco(); }
+   bool prefypp(void)                 { return first2chars() == "#:"; }
+
+   bool pre(void)                     { return precpp() || precoco() || prefypp(); }
 
    bool blank_or_comment_or_pre(void) { return blank_or_comment() || pre(); }
 
