@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -42,26 +42,27 @@ int Pre_analyzer::analyze(const int pretype)
    {
       case CPP_IF:  case CPP_ENDIF:  case CPP_ELSE:  case CPP_ELIF:
       case COCO_IF: case COCO_ENDIF: case COCO_ELSE: case COCO_ELIF: 
-      case INCLUDE_CPP: case INCLUDE_COCO: break;
+      case FYPP_IF: case FYPP_ENDIF: case FYPP_ELSE: case FYPP_ELIF: 
+      case INCLUDE_CPP: case INCLUDE_COCO: case INCLUDE_FYPP: break;
       default: return this->PRE_NONE;
    }
 
    int r;
    switch(pretype)
    {
-      case CPP_IF: case COCO_IF:
+      case CPP_IF: case COCO_IF: case FYPP_IF:
 	 this->ifelse_stack.push_back(0);
 	 return this->PRE_IF;
-      case CPP_ELIF: case COCO_ELIF:
+      case CPP_ELIF: case COCO_ELIF: case FYPP_ELIF:
 	 return this->PRE_ELIF;
-      case CPP_ELSE: case COCO_ELSE:
+      case CPP_ELSE: case COCO_ELSE: case FYPP_ELSE:
 	 if (!this->ifelse_stack.empty())
 	 {
 	    ifelse_stack.pop_back();
 	    ifelse_stack.push_back(1);
 	 }
 	 return this->PRE_ELSE;
-      case CPP_ENDIF: case COCO_ENDIF:
+      case CPP_ENDIF: case COCO_ENDIF: case FYPP_ENDIF:
 	 r = this->PRE_ENDIF; 
 	 if (!ifelse_stack.empty())
 	 {
