@@ -1,5 +1,5 @@
 /* -copyright-
-#-# Copyright: 2015-2024 Willem Vermin wvermin@gmail.com
+#-# Copyright: 2015-2025 Willem Vermin wvermin@gmail.com
 #-# 
 #-# License: BSD-3-Clause
 #-#  Redistribution and use in source and binary forms, with or without
@@ -242,8 +242,8 @@ void Fortran::do_relabel()
       {
 	 item_nr++;
 
-	 Line_prep p = Line_prep(rest,&prest);
-	 propstruct props = parseline(p); 
+	 Line_prep p            = Line_prep(rest,&prest);
+	 propstruct props       = parseline(p); 
 	 intpairs_t pc          = p.get_pos_encoded();
 	 strings_t labels_found = props.labels;
 	 ints_t label_pos       = props.label_pos;
@@ -256,6 +256,7 @@ void Fortran::do_relabel()
 	 int pregion = 0;
 
 
+
 	 switch(state)
 	 {
 	    case outside:
@@ -302,7 +303,7 @@ void Fortran::do_relabel()
 	       }
 	       break;  // end case outside
 	    case inside:
-	       D(O(props.kind););
+	       D(O(t2n(props.kind)););
 	       switch(props.kind)
 	       {
 		  case SUBROUTINE:
@@ -334,7 +335,7 @@ void Fortran::do_relabel()
 		  case IO:
 		  case GOTO_COMPUTED:
 		  case GOTO_ASSIGNED:
-		     D(O("io or computed/assigned goto"););
+		     D(O("call, io, computed/assigned goto");O(props.kind););
 		     D(O(props.lrvalue);O(props.lrpos););
 		     labstring = props.lrvalue;
 		     D(O("labstring");O(labstring););
@@ -400,7 +401,7 @@ void Fortran::do_relabel()
 		  case READ:
 		  case PRINT:
 		     pregion = c_lines[0].preregion();
-		     D(O("do-goto-nwayif-assign-read");O(labels_found.size()););
+		     D(O("do-goto-nwayif-assign-read");O(t2n(props.kind));O(labels_found.size()););
 		     for (size_t num = 0; num < labels_found.size(); num++)
 		     {
 			std::string l = labels_found[num];
@@ -701,11 +702,11 @@ void Fortran::rel_apply()
 {
 
    DL(
-   for (std::map <std::string,std::string>::iterator it=labels.begin(); it != labels.end(); ++it)
-   {
-      D(O("map: ");O(it->first);O(" -> ");O(it->second););
-   }
-   );
+	 for (std::map <std::string,std::string>::iterator it=labels.begin(); it != labels.end(); ++it)
+	 {
+	 D(O("map: ");O(it->first);O(" -> ");O(it->second););
+	 }
+     );
 
    //
    // loop over stored lines
